You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@kudu.apache.org by jd...@apache.org on 2016/02/17 01:42:40 UTC

[1/5] incubator-kudu git commit: [java] ITBLL's Verify always fail since last patch

Repository: incubator-kudu
Updated Branches:
  refs/heads/master d179a7e53 -> 3378c7c06


[java] ITBLL's Verify always fail since last patch

I forgot a return...

Change-Id: Idf890d781eea632dbd64f1cfb74a6c608cd1db4a
Reviewed-on: http://gerrit.cloudera.org:8080/2141
Reviewed-by: Francesco Sorrentino
Tested-by: Kudu Jenkins
Reviewed-by: Todd Lipcon <to...@apache.org>


Project: http://git-wip-us.apache.org/repos/asf/incubator-kudu/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-kudu/commit/88ddc9d2
Tree: http://git-wip-us.apache.org/repos/asf/incubator-kudu/tree/88ddc9d2
Diff: http://git-wip-us.apache.org/repos/asf/incubator-kudu/diff/88ddc9d2

Branch: refs/heads/master
Commit: 88ddc9d281b936a6cfc02de3439ef0775d6b21ef
Parents: d179a7e
Author: Jean-Daniel Cryans <jd...@apache.org>
Authored: Thu Feb 11 19:14:20 2016 -0800
Committer: Jean-Daniel Cryans <jd...@gerrit.cloudera.org>
Committed: Fri Feb 12 16:02:39 2016 +0000

----------------------------------------------------------------------
 .../org/kududb/mapreduce/tools/IntegrationTestBigLinkedList.java    | 1 +
 1 file changed, 1 insertion(+)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-kudu/blob/88ddc9d2/java/kudu-client-tools/src/main/java/org/kududb/mapreduce/tools/IntegrationTestBigLinkedList.java
----------------------------------------------------------------------
diff --git a/java/kudu-client-tools/src/main/java/org/kududb/mapreduce/tools/IntegrationTestBigLinkedList.java b/java/kudu-client-tools/src/main/java/org/kududb/mapreduce/tools/IntegrationTestBigLinkedList.java
index ec10829..1024f50 100644
--- a/java/kudu-client-tools/src/main/java/org/kududb/mapreduce/tools/IntegrationTestBigLinkedList.java
+++ b/java/kudu-client-tools/src/main/java/org/kududb/mapreduce/tools/IntegrationTestBigLinkedList.java
@@ -974,6 +974,7 @@ public class IntegrationTestBigLinkedList extends Configured implements Tool {
         } else {
           fs.delete(iterationOutput, true);
           LOG.info("Verify finished with success. Total nodes=" + expectedNumNodes);
+          return;
         }
       }
       throw new RuntimeException("Ran out of retries to verify");


[2/5] incubator-kudu git commit: Fix wrong code blocks in the document

Posted by jd...@apache.org.
Fix wrong code blocks in the document

Change-Id: I93c27c8f7e4dbe198478cbe2f80eed037171eac5
Reviewed-on: http://gerrit.cloudera.org:8080/2144
Tested-by: Kudu Jenkins
Reviewed-by: Todd Lipcon <to...@apache.org>


Project: http://git-wip-us.apache.org/repos/asf/incubator-kudu/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-kudu/commit/682c664d
Tree: http://git-wip-us.apache.org/repos/asf/incubator-kudu/tree/682c664d
Diff: http://git-wip-us.apache.org/repos/asf/incubator-kudu/diff/682c664d

Branch: refs/heads/master
Commit: 682c664d54111dc923c5960779231a93e3bf098f
Parents: 88ddc9d
Author: Akihiro Okuno <ch...@gmail.com>
Authored: Sat Feb 13 00:06:50 2016 +0900
Committer: Todd Lipcon <to...@apache.org>
Committed: Sat Feb 13 00:59:42 2016 +0000

----------------------------------------------------------------------
 docs/kudu_impala_integration.adoc | 3 +--
 1 file changed, 1 insertion(+), 2 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-kudu/blob/682c664d/docs/kudu_impala_integration.adoc
----------------------------------------------------------------------
diff --git a/docs/kudu_impala_integration.adoc b/docs/kudu_impala_integration.adoc
index af357c2..9444343 100755
--- a/docs/kudu_impala_integration.adoc
+++ b/docs/kudu_impala_integration.adoc
@@ -771,8 +771,6 @@ The example creates 16 buckets. You could also use `HASH (id, sku) INTO 16 BUCKE
 However, a scan for `sku` values would almost always impact all 16 buckets, rather
 than possibly being limited to 4.
 
-----
-
 [[partitioning_rules_of_thumb]]
 ==== Partitioning Rules of Thumb
 
@@ -803,6 +801,7 @@ This example inserts three rows using a single statement.
 [source,sql]
 ----
 INSERT INTO my_first_table VALUES (1, "john"), (2, "jane"), (3, "jim");
+----
 
 [[kudu_impala_insert_bulk]]
 ==== Inserting In Bulk


[5/5] incubator-kudu git commit: Fix CSD and C++11 doc

Posted by jd...@apache.org.
Fix CSD and C++11 doc

This takes care of a few things Stack noticed. For the CSD, I moved
it at the end of the README since the way it is right now a reader
might think it necessary to run it since it's before unit tests.

Change-Id: Ia29cc1dc2f5180ca5c32843aa6c9fedb13ee8b56
Reviewed-on: http://gerrit.cloudera.org:8080/2182
Tested-by: Kudu Jenkins
Reviewed-by: Todd Lipcon <to...@apache.org>


Project: http://git-wip-us.apache.org/repos/asf/incubator-kudu/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-kudu/commit/3378c7c0
Tree: http://git-wip-us.apache.org/repos/asf/incubator-kudu/tree/3378c7c0
Diff: http://git-wip-us.apache.org/repos/asf/incubator-kudu/diff/3378c7c0

Branch: refs/heads/master
Commit: 3378c7c0658b26da61ba186a2c92c949c6efb22a
Parents: 31058c6
Author: Jean-Daniel Cryans <jd...@apache.org>
Authored: Tue Feb 16 14:56:33 2016 -0800
Committer: Jean-Daniel Cryans <jd...@gerrit.cloudera.org>
Committed: Wed Feb 17 00:21:08 2016 +0000

----------------------------------------------------------------------
 docs/installation.adoc |  6 +++--
 java/README.md         | 63 ++++++++++++++++++---------------------------
 2 files changed, 29 insertions(+), 40 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-kudu/blob/3378c7c0/docs/installation.adoc
----------------------------------------------------------------------
diff --git a/docs/installation.adoc b/docs/installation.adoc
index a695bcd..bfaac6e 100644
--- a/docs/installation.adoc
+++ b/docs/installation.adoc
@@ -241,7 +241,8 @@ $ git clone https://github.com/cloudera/kudu
 $ cd kudu
 ----
 
-. Build any missing third-party requirements using the `build-if-necessary.sh` script.
+. Build any missing third-party requirements using the `build-if-necessary.sh` script. Not using
+the devtoolset will result in `Host compiler appears to require libatomic, but cannot find it.`
 +
 [source,bash]
 ----
@@ -250,7 +251,8 @@ $ build-support/enable_devtoolset.sh thirdparty/build-if-necessary.sh
 
 . Build Kudu, using the utilities installed in the previous step. Choose a build
 directory for the intermediate output, which can be anywhere in your filesystem
-except for the `kudu` directory itself.
+except for the `kudu` directory itself. Notice that the devtoolset must still be specified,
+else you'll get `cc1plus: error: unrecognized command line option "-std=c++11"`.
 +
 [source,bash]
 ----

http://git-wip-us.apache.org/repos/asf/incubator-kudu/blob/3378c7c0/java/README.md
----------------------------------------------------------------------
diff --git a/java/README.md b/java/README.md
index 326c29b..157aafd 100644
--- a/java/README.md
+++ b/java/README.md
@@ -29,33 +29,10 @@ $ mvn package -DskipTests
 The client jar will can then be found at kudu-client/target.
 
 
-Building the Kudu CSD
-------------------------------------------------------------
-
-By default, the Kudu CSD will not be built with the client.
-It requires access to the Kudu binaries which may not be
-available. For example, when building on OSX.
-
-Here's how to build the kudu-csd module:
-
-$ mvn package -DskipTests -PbuildCSD
-
-Also by default, building the CSD does not validate it,
-because (for the moment) this requires access to an internal
-Cloudera repository containing the validator maven plugin.
-
-Here's how to build the kudu-csd module with validation:
-
-$ mvn package -DskipTests -PbuildCSD -PvalidateCSD
-
-
 Running the Tests
 ------------------------------------------------------------
 
-Most of the unit tests will start their own cluster but it
-is also possible to provide your own.
-
-By default, the unit tests will start a master and a tablet
+The unit tests will start a master and a tablet
 server using the flags file located in the src/test/resources/
 directory. The tests will locate the master and tablet server
 binaries by looking in 'build/latest/bin' from the root of
@@ -66,20 +43,8 @@ Once everything is setup correctly, run:
 
 $ mvn test
 
-In order to point the unit tests to an existing cluster,
-you need to use a command line like this one:
-
-$ mvn test -DstartCluster=false
-
-If you choose to not start a cluster, the tests will look for
-a master running on localhost:7051. If you would like to run
-against a remote cluster, you can override this using
--DmasterAddress:
-
-$ mvn test -DstartCluster=false -DmasterAddress=foo.example.com:7051
-
-If for some reason you would like to start a cluster, but use
-binaries other than the ones in build/latest/, you can pass
+If for some reason the binaries aren't in the expected location
+as shown above, you can pass
 -DbinDir=/path/to/directory.
 
 Integration tests, including tests which cover Hadoop integration,
@@ -158,3 +123,25 @@ likely a bug in maven-protoc-plugin.
 
 There's a simple workaround: delete the errant folder within
 Eclipse and refresh the kudu-client project.
+
+
+Building the Kudu Custom Service Descriptor (CSD)
+------------------------------------------------------------
+
+By default, the Kudu CSD will not be built with the client
+and isn't needed by any API.
+
+It requires access to the Kudu binaries which have to be built
+prior to building this module.
+
+Here's how to build the kudu-csd module:
+
+$ mvn package -DskipTests -PbuildCSD
+
+Also by default, building the CSD does not validate it,
+because (for the moment) this requires access to an internal
+Cloudera repository containing the validator maven plugin.
+
+Here's how to build the kudu-csd module with validation:
+
+$ mvn package -DskipTests -PbuildCSD -PvalidateCSD
\ No newline at end of file


[3/5] incubator-kudu git commit: Allow to have more chains in linked_list-test

Posted by jd...@apache.org.
Allow to have more chains in linked_list-test

LinkedListTest is one of our most used tests for correcness, but
it has a small maximum number of chains (256) which means that batches
are also accordingly small. This raises that limit to 65536 so that we
can make these tests submit larger batches.

Change-Id: Ideda1bfd130377792528d8bede1e7c44b4cf938f
Reviewed-on: http://gerrit.cloudera.org:8080/2125
Tested-by: Kudu Jenkins
Reviewed-by: Todd Lipcon <to...@apache.org>


Project: http://git-wip-us.apache.org/repos/asf/incubator-kudu/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-kudu/commit/1ba70303
Tree: http://git-wip-us.apache.org/repos/asf/incubator-kudu/tree/1ba70303
Diff: http://git-wip-us.apache.org/repos/asf/incubator-kudu/diff/1ba70303

Branch: refs/heads/master
Commit: 1ba703035c8d1b5327321d5b6a3f28d6bb3c1158
Parents: 682c664
Author: David Alves <da...@cloudera.com>
Authored: Thu Feb 11 12:20:16 2016 -0800
Committer: David Ribeiro Alves <da...@cloudera.com>
Committed: Tue Feb 16 20:26:21 2016 +0000

----------------------------------------------------------------------
 src/kudu/integration-tests/linked_list-test-util.h | 11 ++++++-----
 1 file changed, 6 insertions(+), 5 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-kudu/blob/1ba70303/src/kudu/integration-tests/linked_list-test-util.h
----------------------------------------------------------------------
diff --git a/.gitignore b/.gitignore
index a55a351..ef6586f 100644
--- a/.gitignore
+++ b/.gitignore
@@ -1,3 +1,20 @@
+# Licensed to the Apache Software Foundation (ASF) under one
+# or more contributor license agreements.  See the NOTICE file
+# distributed with this work for additional information
+# regarding copyright ownership.  The ASF licenses this file
+# to you under the Apache License, Version 2.0 (the
+# "License"); you may not use this file except in compliance
+# with the License.  You may obtain a copy of the License at
+#
+#   http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing,
+# software distributed under the License is distributed on an
+# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+# KIND, either express or implied.  See the License for the
+# specific language governing permissions and limitations
+# under the License.
+
 # Most common in-tree build directory.
 #
 # Note: build output files are not explicitly listed here because they are

http://git-wip-us.apache.org/repos/asf/incubator-kudu/blob/31058c6c/build-support/jenkins/dummy-junit.xml
----------------------------------------------------------------------
diff --git a/build-support/jenkins/dummy-junit.xml b/build-support/jenkins/dummy-junit.xml
index 1f02612..ae128c5 100644
--- a/build-support/jenkins/dummy-junit.xml
+++ b/build-support/jenkins/dummy-junit.xml
@@ -1,3 +1,21 @@
+<!--
+// Licensed to the Apache Software Foundation (ASF) under one
+// or more contributor license agreements.  See the NOTICE file
+// distributed with this work for additional information
+// regarding copyright ownership.  The ASF licenses this file
+// to you under the Apache License, Version 2.0 (the
+// "License"); you may not use this file except in compliance
+// with the License.  You may obtain a copy of the License at
+//
+//   http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing,
+// software distributed under the License is distributed on an
+// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+// KIND, either express or implied.  See the License for the
+// specific language governing permissions and limitations
+// under the License.
+-->
 <!-- There must be at least one junit xml file found in its search paths or the
      Jenkins surefire plugin will fail. This file is left here to make the LINT
      build pass, since it does not run any unit tests.

http://git-wip-us.apache.org/repos/asf/incubator-kudu/blob/31058c6c/build-support/tools/kudu-lint/.gitignore
----------------------------------------------------------------------
diff --git a/build-support/tools/kudu-lint/.gitignore b/build-support/tools/kudu-lint/.gitignore
index d78d765..5e1caf5 100644
--- a/build-support/tools/kudu-lint/.gitignore
+++ b/build-support/tools/kudu-lint/.gitignore
@@ -1,2 +1,19 @@
+# Licensed to the Apache Software Foundation (ASF) under one
+# or more contributor license agreements.  See the NOTICE file
+# distributed with this work for additional information
+# regarding copyright ownership.  The ASF licenses this file
+# to you under the Apache License, Version 2.0 (the
+# "License"); you may not use this file except in compliance
+# with the License.  You may obtain a copy of the License at
+#
+#   http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing,
+# software distributed under the License is distributed on an
+# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+# KIND, either express or implied.  See the License for the
+# specific language governing permissions and limitations
+# under the License.
+
 # The binary
 kudu-lint

http://git-wip-us.apache.org/repos/asf/incubator-kudu/blob/31058c6c/cmake_modules/FindBitshuffle.cmake
----------------------------------------------------------------------
diff --git a/cmake_modules/FindBitshuffle.cmake b/cmake_modules/FindBitshuffle.cmake
index ed9b04d..8caae64 100644
--- a/cmake_modules/FindBitshuffle.cmake
+++ b/cmake_modules/FindBitshuffle.cmake
@@ -1,3 +1,20 @@
+# Licensed to the Apache Software Foundation (ASF) under one
+# or more contributor license agreements.  See the NOTICE file
+# distributed with this work for additional information
+# regarding copyright ownership.  The ASF licenses this file
+# to you under the Apache License, Version 2.0 (the
+# "License"); you may not use this file except in compliance
+# with the License.  You may obtain a copy of the License at
+#
+#   http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing,
+# software distributed under the License is distributed on an
+# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+# KIND, either express or implied.  See the License for the
+# specific language governing permissions and limitations
+# under the License.
+
 # - Find Bitshuffle (bitshuffle.h, bitshuffle.a)
 # This module defines
 #  BITSHUFFLE_INCLUDE_DIR, directory containing headers

http://git-wip-us.apache.org/repos/asf/incubator-kudu/blob/31058c6c/cmake_modules/FindCrcutil.cmake
----------------------------------------------------------------------
diff --git a/cmake_modules/FindCrcutil.cmake b/cmake_modules/FindCrcutil.cmake
index 6d93a9a..6866348 100644
--- a/cmake_modules/FindCrcutil.cmake
+++ b/cmake_modules/FindCrcutil.cmake
@@ -1,3 +1,20 @@
+# Licensed to the Apache Software Foundation (ASF) under one
+# or more contributor license agreements.  See the NOTICE file
+# distributed with this work for additional information
+# regarding copyright ownership.  The ASF licenses this file
+# to you under the Apache License, Version 2.0 (the
+# "License"); you may not use this file except in compliance
+# with the License.  You may obtain a copy of the License at
+#
+#   http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing,
+# software distributed under the License is distributed on an
+# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+# KIND, either express or implied.  See the License for the
+# specific language governing permissions and limitations
+# under the License.
+
 # - Find CRCUTIL (crcutil/include.h, libcrcutil.a)
 # This module defines
 #  CRCUTIL_INCLUDE_DIR, directory containing headers

http://git-wip-us.apache.org/repos/asf/incubator-kudu/blob/31058c6c/cmake_modules/FindGFlags.cmake
----------------------------------------------------------------------
diff --git a/cmake_modules/FindGFlags.cmake b/cmake_modules/FindGFlags.cmake
index 273c72e..acfbccd 100644
--- a/cmake_modules/FindGFlags.cmake
+++ b/cmake_modules/FindGFlags.cmake
@@ -1,3 +1,20 @@
+# Licensed to the Apache Software Foundation (ASF) under one
+# or more contributor license agreements.  See the NOTICE file
+# distributed with this work for additional information
+# regarding copyright ownership.  The ASF licenses this file
+# to you under the Apache License, Version 2.0 (the
+# "License"); you may not use this file except in compliance
+# with the License.  You may obtain a copy of the License at
+#
+#   http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing,
+# software distributed under the License is distributed on an
+# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+# KIND, either express or implied.  See the License for the
+# specific language governing permissions and limitations
+# under the License.
+
 # - Find GFLAGS (gflags.h, libgflags.a, libgflags.so, and libgflags.so.0)
 # This module defines
 #  GFLAGS_INCLUDE_DIR, directory containing headers

http://git-wip-us.apache.org/repos/asf/incubator-kudu/blob/31058c6c/cmake_modules/FindGLog.cmake
----------------------------------------------------------------------
diff --git a/cmake_modules/FindGLog.cmake b/cmake_modules/FindGLog.cmake
index c214bd0..c9876b7 100644
--- a/cmake_modules/FindGLog.cmake
+++ b/cmake_modules/FindGLog.cmake
@@ -1,3 +1,20 @@
+# Licensed to the Apache Software Foundation (ASF) under one
+# or more contributor license agreements.  See the NOTICE file
+# distributed with this work for additional information
+# regarding copyright ownership.  The ASF licenses this file
+# to you under the Apache License, Version 2.0 (the
+# "License"); you may not use this file except in compliance
+# with the License.  You may obtain a copy of the License at
+#
+#   http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing,
+# software distributed under the License is distributed on an
+# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+# KIND, either express or implied.  See the License for the
+# specific language governing permissions and limitations
+# under the License.
+
 # - Find GLOG (logging.h, libglog.a, libglog.so, and libglog.so.0)
 # This module defines
 #  GLOG_INCLUDE_DIR, directory containing headers

http://git-wip-us.apache.org/repos/asf/incubator-kudu/blob/31058c6c/cmake_modules/FindGPerf.cmake
----------------------------------------------------------------------
diff --git a/cmake_modules/FindGPerf.cmake b/cmake_modules/FindGPerf.cmake
index 48d4033..d3ed697 100644
--- a/cmake_modules/FindGPerf.cmake
+++ b/cmake_modules/FindGPerf.cmake
@@ -1,3 +1,20 @@
+# Licensed to the Apache Software Foundation (ASF) under one
+# or more contributor license agreements.  See the NOTICE file
+# distributed with this work for additional information
+# regarding copyright ownership.  The ASF licenses this file
+# to you under the Apache License, Version 2.0 (the
+# "License"); you may not use this file except in compliance
+# with the License.  You may obtain a copy of the License at
+#
+#   http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing,
+# software distributed under the License is distributed on an
+# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+# KIND, either express or implied.  See the License for the
+# specific language governing permissions and limitations
+# under the License.
+
 # -*- cmake -*-
 
 # - Find Google perftools

http://git-wip-us.apache.org/repos/asf/incubator-kudu/blob/31058c6c/cmake_modules/FindLibEv.cmake
----------------------------------------------------------------------
diff --git a/cmake_modules/FindLibEv.cmake b/cmake_modules/FindLibEv.cmake
index f1f9d7a..c2cfbd3 100644
--- a/cmake_modules/FindLibEv.cmake
+++ b/cmake_modules/FindLibEv.cmake
@@ -1,3 +1,20 @@
+# Licensed to the Apache Software Foundation (ASF) under one
+# or more contributor license agreements.  See the NOTICE file
+# distributed with this work for additional information
+# regarding copyright ownership.  The ASF licenses this file
+# to you under the Apache License, Version 2.0 (the
+# "License"); you may not use this file except in compliance
+# with the License.  You may obtain a copy of the License at
+#
+#   http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing,
+# software distributed under the License is distributed on an
+# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+# KIND, either express or implied.  See the License for the
+# specific language governing permissions and limitations
+# under the License.
+
 # - Find LIBEV (ev++.h, libev.a, and libev.so)
 # This module defines
 #  LIBEV_INCLUDE_DIR, directory containing headers

http://git-wip-us.apache.org/repos/asf/incubator-kudu/blob/31058c6c/cmake_modules/FindLz4.cmake
----------------------------------------------------------------------
diff --git a/cmake_modules/FindLz4.cmake b/cmake_modules/FindLz4.cmake
index 87800a8..362d493 100644
--- a/cmake_modules/FindLz4.cmake
+++ b/cmake_modules/FindLz4.cmake
@@ -1,3 +1,20 @@
+# Licensed to the Apache Software Foundation (ASF) under one
+# or more contributor license agreements.  See the NOTICE file
+# distributed with this work for additional information
+# regarding copyright ownership.  The ASF licenses this file
+# to you under the Apache License, Version 2.0 (the
+# "License"); you may not use this file except in compliance
+# with the License.  You may obtain a copy of the License at
+#
+#   http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing,
+# software distributed under the License is distributed on an
+# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+# KIND, either express or implied.  See the License for the
+# specific language governing permissions and limitations
+# under the License.
+
 # - Find LZ4 (lz4.h, liblz4.a)
 # This module defines
 #  LZ4_INCLUDE_DIR, directory containing headers

http://git-wip-us.apache.org/repos/asf/incubator-kudu/blob/31058c6c/cmake_modules/FindProtobuf.cmake
----------------------------------------------------------------------
diff --git a/cmake_modules/FindProtobuf.cmake b/cmake_modules/FindProtobuf.cmake
index 108d68c..128bbf2 100644
--- a/cmake_modules/FindProtobuf.cmake
+++ b/cmake_modules/FindProtobuf.cmake
@@ -1,3 +1,20 @@
+# Licensed to the Apache Software Foundation (ASF) under one
+# or more contributor license agreements.  See the NOTICE file
+# distributed with this work for additional information
+# regarding copyright ownership.  The ASF licenses this file
+# to you under the Apache License, Version 2.0 (the
+# "License"); you may not use this file except in compliance
+# with the License.  You may obtain a copy of the License at
+#
+#   http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing,
+# software distributed under the License is distributed on an
+# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+# KIND, either express or implied.  See the License for the
+# specific language governing permissions and limitations
+# under the License.
+
 #########
 # Local rewrite of the protobuf support in cmake.
 #

http://git-wip-us.apache.org/repos/asf/incubator-kudu/blob/31058c6c/cmake_modules/FindSnappy.cmake
----------------------------------------------------------------------
diff --git a/cmake_modules/FindSnappy.cmake b/cmake_modules/FindSnappy.cmake
index 75a909f..20d5ace 100644
--- a/cmake_modules/FindSnappy.cmake
+++ b/cmake_modules/FindSnappy.cmake
@@ -1,3 +1,20 @@
+# Licensed to the Apache Software Foundation (ASF) under one
+# or more contributor license agreements.  See the NOTICE file
+# distributed with this work for additional information
+# regarding copyright ownership.  The ASF licenses this file
+# to you under the Apache License, Version 2.0 (the
+# "License"); you may not use this file except in compliance
+# with the License.  You may obtain a copy of the License at
+#
+#   http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing,
+# software distributed under the License is distributed on an
+# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+# KIND, either express or implied.  See the License for the
+# specific language governing permissions and limitations
+# under the License.
+
 # - Find SNAPPY (snappy.h, libsnappy.a, libsnappy.so, and libsnappy.so.1)
 # This module defines
 #  SNAPPY_INCLUDE_DIR, directory containing headers

http://git-wip-us.apache.org/repos/asf/incubator-kudu/blob/31058c6c/cmake_modules/FindVmem.cmake
----------------------------------------------------------------------
diff --git a/cmake_modules/FindVmem.cmake b/cmake_modules/FindVmem.cmake
index b85d2c4..6c2e0de 100644
--- a/cmake_modules/FindVmem.cmake
+++ b/cmake_modules/FindVmem.cmake
@@ -1,3 +1,20 @@
+# Licensed to the Apache Software Foundation (ASF) under one
+# or more contributor license agreements.  See the NOTICE file
+# distributed with this work for additional information
+# regarding copyright ownership.  The ASF licenses this file
+# to you under the Apache License, Version 2.0 (the
+# "License"); you may not use this file except in compliance
+# with the License.  You may obtain a copy of the License at
+#
+#   http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing,
+# software distributed under the License is distributed on an
+# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+# KIND, either express or implied.  See the License for the
+# specific language governing permissions and limitations
+# under the License.
+
 # - Find VMEM (libvmem.h, libvmem.so)
 # This module defines
 #  VMEM_INCLUDE_DIR, directory containing headers

http://git-wip-us.apache.org/repos/asf/incubator-kudu/blob/31058c6c/cmake_modules/FindZlib.cmake
----------------------------------------------------------------------
diff --git a/cmake_modules/FindZlib.cmake b/cmake_modules/FindZlib.cmake
index ee8078b..48d7b01 100644
--- a/cmake_modules/FindZlib.cmake
+++ b/cmake_modules/FindZlib.cmake
@@ -1,3 +1,20 @@
+# Licensed to the Apache Software Foundation (ASF) under one
+# or more contributor license agreements.  See the NOTICE file
+# distributed with this work for additional information
+# regarding copyright ownership.  The ASF licenses this file
+# to you under the Apache License, Version 2.0 (the
+# "License"); you may not use this file except in compliance
+# with the License.  You may obtain a copy of the License at
+#
+#   http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing,
+# software distributed under the License is distributed on an
+# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+# KIND, either express or implied.  See the License for the
+# specific language governing permissions and limitations
+# under the License.
+
 # - Find ZLIB (zlib.h, libz.a, libz.so, and libz.so.1)
 # This module defines
 #  ZLIB_INCLUDE_DIR, directory containing headers

http://git-wip-us.apache.org/repos/asf/incubator-kudu/blob/31058c6c/docs/.gitignore
----------------------------------------------------------------------
diff --git a/docs/.gitignore b/docs/.gitignore
index 3432c3f..9e71527 100644
--- a/docs/.gitignore
+++ b/docs/.gitignore
@@ -1,2 +1,19 @@
+# Licensed to the Apache Software Foundation (ASF) under one
+# or more contributor license agreements.  See the NOTICE file
+# distributed with this work for additional information
+# regarding copyright ownership.  The ASF licenses this file
+# to you under the Apache License, Version 2.0 (the
+# "License"); you may not use this file except in compliance
+# with the License.  You may obtain a copy of the License at
+#
+#   http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing,
+# software distributed under the License is distributed on an
+# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+# KIND, either express or implied.  See the License for the
+# specific language governing permissions and limitations
+# under the License.
+
 *.html
 

http://git-wip-us.apache.org/repos/asf/incubator-kudu/blob/31058c6c/docs/images/.gitignore
----------------------------------------------------------------------
diff --git a/docs/images/.gitignore b/docs/images/.gitignore
deleted file mode 100644
index e69de29..0000000

http://git-wip-us.apache.org/repos/asf/incubator-kudu/blob/31058c6c/docs/support/scripts/Gemfile
----------------------------------------------------------------------
diff --git a/docs/support/scripts/Gemfile b/docs/support/scripts/Gemfile
index cc67e62..2948545 100644
--- a/docs/support/scripts/Gemfile
+++ b/docs/support/scripts/Gemfile
@@ -1,3 +1,20 @@
+# Licensed to the Apache Software Foundation (ASF) under one
+# or more contributor license agreements.  See the NOTICE file
+# distributed with this work for additional information
+# regarding copyright ownership.  The ASF licenses this file
+# to you under the Apache License, Version 2.0 (the
+# "License"); you may not use this file except in compliance
+# with the License.  You may obtain a copy of the License at
+#
+#   http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing,
+# software distributed under the License is distributed on an
+# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+# KIND, either express or implied.  See the License for the
+# specific language governing permissions and limitations
+# under the License.
+
 source 'https://rubygems.org'
 
 # We need to use versions that can run on CentOS 6, which ships Ruby 1.8.7.

http://git-wip-us.apache.org/repos/asf/incubator-kudu/blob/31058c6c/docs/transaction_semantics.adoc
----------------------------------------------------------------------
diff --git a/docs/transaction_semantics.adoc b/docs/transaction_semantics.adoc
index b2c51c4..9e80211 100644
--- a/docs/transaction_semantics.adoc
+++ b/docs/transaction_semantics.adoc
@@ -1,3 +1,20 @@
+// Licensed to the Apache Software Foundation (ASF) under one
+// or more contributor license agreements.  See the NOTICE file
+// distributed with this work for additional information
+// regarding copyright ownership.  The ASF licenses this file
+// to you under the Apache License, Version 2.0 (the
+// "License"); you may not use this file except in compliance
+// with the License.  You may obtain a copy of the License at
+//
+//   http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing,
+// software distributed under the License is distributed on an
+// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+// KIND, either express or implied.  See the License for the
+// specific language governing permissions and limitations
+// under the License.
+
 [[installation]]
 = Transaction Semantics in Apache Kudu (incubating)
 

http://git-wip-us.apache.org/repos/asf/incubator-kudu/blob/31058c6c/docs/whitepaper/.gitignore
----------------------------------------------------------------------
diff --git a/docs/whitepaper/.gitignore b/docs/whitepaper/.gitignore
index 3eec47d..ac8fdb7 100644
--- a/docs/whitepaper/.gitignore
+++ b/docs/whitepaper/.gitignore
@@ -1,3 +1,20 @@
+# Licensed to the Apache Software Foundation (ASF) under one
+# or more contributor license agreements.  See the NOTICE file
+# distributed with this work for additional information
+# regarding copyright ownership.  The ASF licenses this file
+# to you under the Apache License, Version 2.0 (the
+# "License"); you may not use this file except in compliance
+# with the License.  You may obtain a copy of the License at
+#
+#   http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing,
+# software distributed under the License is distributed on an
+# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+# KIND, either express or implied.  See the License for the
+# specific language governing permissions and limitations
+# under the License.
+
 *.aux
 *.log
 *.pdf

http://git-wip-us.apache.org/repos/asf/incubator-kudu/blob/31058c6c/docs/whitepaper/kudu.tex
----------------------------------------------------------------------
diff --git a/docs/whitepaper/kudu.tex b/docs/whitepaper/kudu.tex
index 750bf0f..53baf48 100644
--- a/docs/whitepaper/kudu.tex
+++ b/docs/whitepaper/kudu.tex
@@ -1,4 +1,20 @@
-% Confidential Cloudera Information, covered by NDA.
+% Licensed to the Apache Software Foundation (ASF) under one
+% or more contributor license agreements.  See the NOTICE file
+% distributed with this work for additional information
+% regarding copyright ownership.  The ASF licenses this file
+% to you under the Apache License, Version 2.0 (the
+% "License"); you may not use this file except in compliance
+% with the License.  You may obtain a copy of the License at
+%
+%   http://www.apache.org/licenses/LICENSE-2.0
+%
+% Unless required by applicable law or agreed to in writing,
+% software distributed under the License is distributed on an
+% "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+% KIND, either express or implied.  See the License for the
+% specific language governing permissions and limitations
+% under the License.
+
 \documentclass{vldb}
 \usepackage{graphicx}
 \usepackage{verbatim}

http://git-wip-us.apache.org/repos/asf/incubator-kudu/blob/31058c6c/docs/whitepaper/ycsb-data/combine-data.sh
----------------------------------------------------------------------
diff --git a/docs/whitepaper/ycsb-data/combine-data.sh b/docs/whitepaper/ycsb-data/combine-data.sh
index 087ac7b..e600be2 100755
--- a/docs/whitepaper/ycsb-data/combine-data.sh
+++ b/docs/whitepaper/ycsb-data/combine-data.sh
@@ -1,4 +1,21 @@
 #!/bin/bash
+#
+# Licensed to the Apache Software Foundation (ASF) under one
+# or more contributor license agreements.  See the NOTICE file
+# distributed with this work for additional information
+# regarding copyright ownership.  The ASF licenses this file
+# to you under the Apache License, Version 2.0 (the
+# "License"); you may not use this file except in compliance
+# with the License.  You may obtain a copy of the License at
+#
+#   http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing,
+# software distributed under the License is distributed on an
+# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+# KIND, either express or implied.  See the License for the
+# specific language governing permissions and limitations
+# under the License.
 
 prepend_lines() {
   tail --lines=+2 $1 | perl -p -e "s,^,$2,g;"

http://git-wip-us.apache.org/repos/asf/incubator-kudu/blob/31058c6c/docs/whitepaper/ycsb-data/log-to-tsv.pl
----------------------------------------------------------------------
diff --git a/docs/whitepaper/ycsb-data/log-to-tsv.pl b/docs/whitepaper/ycsb-data/log-to-tsv.pl
index feff455..b24b119 100755
--- a/docs/whitepaper/ycsb-data/log-to-tsv.pl
+++ b/docs/whitepaper/ycsb-data/log-to-tsv.pl
@@ -1,4 +1,21 @@
 #!/usr/bin/env perl
+#
+# Licensed to the Apache Software Foundation (ASF) under one
+# or more contributor license agreements.  See the NOTICE file
+# distributed with this work for additional information
+# regarding copyright ownership.  The ASF licenses this file
+# to you under the Apache License, Version 2.0 (the
+# "License"); you may not use this file except in compliance
+# with the License.  You may obtain a copy of the License at
+#
+#   http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing,
+# software distributed under the License is distributed on an
+# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+# KIND, either express or implied.  See the License for the
+# specific language governing permissions and limitations
+# under the License.
 
 print "time\ttput\n";
 while (<>) {

http://git-wip-us.apache.org/repos/asf/incubator-kudu/blob/31058c6c/docs/whitepaper/ycsb-data/plots.R
----------------------------------------------------------------------
diff --git a/docs/whitepaper/ycsb-data/plots.R b/docs/whitepaper/ycsb-data/plots.R
index aeda345..3090b03 100644
--- a/docs/whitepaper/ycsb-data/plots.R
+++ b/docs/whitepaper/ycsb-data/plots.R
@@ -1,3 +1,20 @@
+# Licensed to the Apache Software Foundation (ASF) under one
+# or more contributor license agreements.  See the NOTICE file
+# distributed with this work for additional information
+# regarding copyright ownership.  The ASF licenses this file
+# to you under the Apache License, Version 2.0 (the
+# "License"); you may not use this file except in compliance
+# with the License.  You may obtain a copy of the License at
+#
+#   http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing,
+# software distributed under the License is distributed on an
+# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+# KIND, either express or implied.  See the License for the
+# specific language governing permissions and limitations
+# under the License.
+
 library(ggplot2)
 library(scales)
 

http://git-wip-us.apache.org/repos/asf/incubator-kudu/blob/31058c6c/docs/whitepaper/ycsb-data/uniform-hbase.sh
----------------------------------------------------------------------
diff --git a/docs/whitepaper/ycsb-data/uniform-hbase.sh b/docs/whitepaper/ycsb-data/uniform-hbase.sh
index 68444c4..1f6bf77 100755
--- a/docs/whitepaper/ycsb-data/uniform-hbase.sh
+++ b/docs/whitepaper/ycsb-data/uniform-hbase.sh
@@ -1,4 +1,21 @@
 #/bin/bash
+#
+# Licensed to the Apache Software Foundation (ASF) under one
+# or more contributor license agreements.  See the NOTICE file
+# distributed with this work for additional information
+# regarding copyright ownership.  The ASF licenses this file
+# to you under the Apache License, Version 2.0 (the
+# "License"); you may not use this file except in compliance
+# with the License.  You may obtain a copy of the License at
+#
+#   http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing,
+# software distributed under the License is distributed on an
+# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+# KIND, either express or implied.  See the License for the
+# specific language governing permissions and limitations
+# under the License.
 
 EXPORTER="com.yahoo.ycsb.measurements.exporter.JSONArrayMeasurementsExporter"
 COMMON_FLAGS="-p recordcount=100000000 -p columnfamily=family -cp /etc/hbase/conf -p exporter=$EXPORTER -p table=ycsb_100m"

http://git-wip-us.apache.org/repos/asf/incubator-kudu/blob/31058c6c/docs/whitepaper/ycsb-data/uniform-kudu.sh
----------------------------------------------------------------------
diff --git a/docs/whitepaper/ycsb-data/uniform-kudu.sh b/docs/whitepaper/ycsb-data/uniform-kudu.sh
index cacd919..735983b 100755
--- a/docs/whitepaper/ycsb-data/uniform-kudu.sh
+++ b/docs/whitepaper/ycsb-data/uniform-kudu.sh
@@ -1,4 +1,21 @@
 #/bin/bash
+#
+# Licensed to the Apache Software Foundation (ASF) under one
+# or more contributor license agreements.  See the NOTICE file
+# distributed with this work for additional information
+# regarding copyright ownership.  The ASF licenses this file
+# to you under the Apache License, Version 2.0 (the
+# "License"); you may not use this file except in compliance
+# with the License.  You may obtain a copy of the License at
+#
+#   http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing,
+# software distributed under the License is distributed on an
+# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+# KIND, either express or implied.  See the License for the
+# specific language governing permissions and limitations
+# under the License.
 
 EXPORTER="com.yahoo.ycsb.measurements.exporter.JSONArrayMeasurementsExporter"
 COMMON_FLAGS="-p recordcount=100000000 -p exporter=$EXPORTER -p table_name=ycsb_100m -p masterQuorum=a1216"

http://git-wip-us.apache.org/repos/asf/incubator-kudu/blob/31058c6c/docs/whitepaper/ycsb-data/zipf-hbase.sh
----------------------------------------------------------------------
diff --git a/docs/whitepaper/ycsb-data/zipf-hbase.sh b/docs/whitepaper/ycsb-data/zipf-hbase.sh
index ea358df..cea59e7 100755
--- a/docs/whitepaper/ycsb-data/zipf-hbase.sh
+++ b/docs/whitepaper/ycsb-data/zipf-hbase.sh
@@ -1,4 +1,21 @@
 #/bin/bash
+#
+# Licensed to the Apache Software Foundation (ASF) under one
+# or more contributor license agreements.  See the NOTICE file
+# distributed with this work for additional information
+# regarding copyright ownership.  The ASF licenses this file
+# to you under the Apache License, Version 2.0 (the
+# "License"); you may not use this file except in compliance
+# with the License.  You may obtain a copy of the License at
+#
+#   http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing,
+# software distributed under the License is distributed on an
+# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+# KIND, either express or implied.  See the License for the
+# specific language governing permissions and limitations
+# under the License.
 
 EXPORTER="com.yahoo.ycsb.measurements.exporter.JSONArrayMeasurementsExporter"
 COMMON_FLAGS="-p recordcount=100000000 -p columnfamily=family -cp /etc/hbase/conf -p exporter=$EXPORTER -p table=ycsb_100m"

http://git-wip-us.apache.org/repos/asf/incubator-kudu/blob/31058c6c/docs/whitepaper/ycsb-data/zipfian-kudu.sh
----------------------------------------------------------------------
diff --git a/docs/whitepaper/ycsb-data/zipfian-kudu.sh b/docs/whitepaper/ycsb-data/zipfian-kudu.sh
index 527304f..acb674e 100755
--- a/docs/whitepaper/ycsb-data/zipfian-kudu.sh
+++ b/docs/whitepaper/ycsb-data/zipfian-kudu.sh
@@ -1,4 +1,21 @@
 #/bin/bash
+#
+# Licensed to the Apache Software Foundation (ASF) under one
+# or more contributor license agreements.  See the NOTICE file
+# distributed with this work for additional information
+# regarding copyright ownership.  The ASF licenses this file
+# to you under the Apache License, Version 2.0 (the
+# "License"); you may not use this file except in compliance
+# with the License.  You may obtain a copy of the License at
+#
+#   http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing,
+# software distributed under the License is distributed on an
+# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+# KIND, either express or implied.  See the License for the
+# specific language governing permissions and limitations
+# under the License.
 
 EXPORTER="com.yahoo.ycsb.measurements.exporter.JSONArrayMeasurementsExporter"
 COMMON_FLAGS="-p recordcount=100000000 -p exporter=$EXPORTER -p table_name=ycsb_100m -p masterQuorum=a1216"

http://git-wip-us.apache.org/repos/asf/incubator-kudu/blob/31058c6c/java/.gitignore
----------------------------------------------------------------------
diff --git a/java/.gitignore b/java/.gitignore
index 02ef3ff..05b8237 100644
--- a/java/.gitignore
+++ b/java/.gitignore
@@ -1,3 +1,20 @@
+# Licensed to the Apache Software Foundation (ASF) under one
+# or more contributor license agreements.  See the NOTICE file
+# distributed with this work for additional information
+# regarding copyright ownership.  The ASF licenses this file
+# to you under the Apache License, Version 2.0 (the
+# "License"); you may not use this file except in compliance
+# with the License.  You may obtain a copy of the License at
+#
+#   http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing,
+# software distributed under the License is distributed on an
+# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+# KIND, either express or implied.  See the License for the
+# specific language governing permissions and limitations
+# under the License.
+
 # Eclipse files
 .classpath
 .project

http://git-wip-us.apache.org/repos/asf/incubator-kudu/blob/31058c6c/java/kudu-client/.gitignore
----------------------------------------------------------------------
diff --git a/java/kudu-client/.gitignore b/java/kudu-client/.gitignore
index 4bc0ed3..3516d86 100644
--- a/java/kudu-client/.gitignore
+++ b/java/kudu-client/.gitignore
@@ -1,3 +1,19 @@
+# Licensed to the Apache Software Foundation (ASF) under one
+# or more contributor license agreements.  See the NOTICE file
+# distributed with this work for additional information
+# regarding copyright ownership.  The ASF licenses this file
+# to you under the Apache License, Version 2.0 (the
+# "License"); you may not use this file except in compliance
+# with the License.  You may obtain a copy of the License at
+#
+#   http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing,
+# software distributed under the License is distributed on an
+# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+# KIND, either express or implied.  See the License for the
+# specific language governing permissions and limitations
+# under the License.
 
 # Maven build artifacts
 dependency-reduced-pom.xml

http://git-wip-us.apache.org/repos/asf/incubator-kudu/blob/31058c6c/python/.gitignore
----------------------------------------------------------------------
diff --git a/python/.gitignore b/python/.gitignore
index 921484a..2e78d86 100644
--- a/python/.gitignore
+++ b/python/.gitignore
@@ -1,16 +1,19 @@
-# Copyright 2016 Cloudera, Inc.
+# Licensed to the Apache Software Foundation (ASF) under one
+# or more contributor license agreements.  See the NOTICE file
+# distributed with this work for additional information
+# regarding copyright ownership.  The ASF licenses this file
+# to you under the Apache License, Version 2.0 (the
+# "License"); you may not use this file except in compliance
+# with the License.  You may obtain a copy of the License at
 #
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
+#   http://www.apache.org/licenses/LICENSE-2.0
 #
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
+# Unless required by applicable law or agreed to in writing,
+# software distributed under the License is distributed on an
+# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+# KIND, either express or implied.  See the License for the
+# specific language governing permissions and limitations
+# under the License.
 
 # Editor temporary/working/backup files
 *flymake*
@@ -40,4 +43,4 @@ dist
 coverage.xml
 
 # automatically generated during local development
-kudu/version.py
\ No newline at end of file
+kudu/version.py

http://git-wip-us.apache.org/repos/asf/incubator-kudu/blob/31058c6c/python/kudu/tests/__init__.py
----------------------------------------------------------------------
diff --git a/python/kudu/tests/__init__.py b/python/kudu/tests/__init__.py
index e69de29..df30457 100644
--- a/python/kudu/tests/__init__.py
+++ b/python/kudu/tests/__init__.py
@@ -0,0 +1,18 @@
+# Licensed to the Apache Software Foundation (ASF) under one
+# or more contributor license agreements.  See the NOTICE file
+# distributed with this work for additional information
+# regarding copyright ownership.  The ASF licenses this file
+# to you under the Apache License, Version 2.0 (the
+# "License"); you may not use this file except in compliance
+# with the License.  You may obtain a copy of the License at
+#
+#   http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing,
+# software distributed under the License is distributed on an
+# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+# KIND, either express or implied.  See the License for the
+# specific language governing permissions and limitations
+# under the License.
+
+# This file left blank.

http://git-wip-us.apache.org/repos/asf/incubator-kudu/blob/31058c6c/src/kudu/client/clientConfig.cmake.in
----------------------------------------------------------------------
diff --git a/src/kudu/client/clientConfig.cmake.in b/src/kudu/client/clientConfig.cmake.in
index 9eaf00c..b788e4e 100644
--- a/src/kudu/client/clientConfig.cmake.in
+++ b/src/kudu/client/clientConfig.cmake.in
@@ -1,3 +1,20 @@
+# Licensed to the Apache Software Foundation (ASF) under one
+# or more contributor license agreements.  See the NOTICE file
+# distributed with this work for additional information
+# regarding copyright ownership.  The ASF licenses this file
+# to you under the Apache License, Version 2.0 (the
+# "License"); you may not use this file except in compliance
+# with the License.  You may obtain a copy of the License at
+#
+#   http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing,
+# software distributed under the License is distributed on an
+# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+# KIND, either express or implied.  See the License for the
+# specific language governing permissions and limitations
+# under the License.
+
 # Workaround so the generated cmake file works in older versions of
 # cmake
 if(NOT CMAKE_CURRENT_LIST_DIR)

http://git-wip-us.apache.org/repos/asf/incubator-kudu/blob/31058c6c/src/kudu/scripts/ensure_cpu_scaling.sh
----------------------------------------------------------------------
diff --git a/src/kudu/scripts/ensure_cpu_scaling.sh b/src/kudu/scripts/ensure_cpu_scaling.sh
index 0de657a..552cb9a 100755
--- a/src/kudu/scripts/ensure_cpu_scaling.sh
+++ b/src/kudu/scripts/ensure_cpu_scaling.sh
@@ -1,4 +1,22 @@
 #!/bin/bash -e
+#
+# Licensed to the Apache Software Foundation (ASF) under one
+# or more contributor license agreements.  See the NOTICE file
+# distributed with this work for additional information
+# regarding copyright ownership.  The ASF licenses this file
+# to you under the Apache License, Version 2.0 (the
+# "License"); you may not use this file except in compliance
+# with the License.  You may obtain a copy of the License at
+#
+#   http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing,
+# software distributed under the License is distributed on an
+# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+# KIND, either express or implied.  See the License for the
+# specific language governing permissions and limitations
+# under the License.
+
 # Ensure that the CPU governor is set to a particular governor, outputting
 # the prior governor on stdout.
 #

http://git-wip-us.apache.org/repos/asf/incubator-kudu/blob/31058c6c/thirdparty/.gitignore
----------------------------------------------------------------------
diff --git a/thirdparty/.gitignore b/thirdparty/.gitignore
index 4d85033..57d7d9f 100644
--- a/thirdparty/.gitignore
+++ b/thirdparty/.gitignore
@@ -1,3 +1,20 @@
+# Licensed to the Apache Software Foundation (ASF) under one
+# or more contributor license agreements.  See the NOTICE file
+# distributed with this work for additional information
+# regarding copyright ownership.  The ASF licenses this file
+# to you under the Apache License, Version 2.0 (the
+# "License"); you may not use this file except in compliance
+# with the License.  You may obtain a copy of the License at
+#
+#   http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing,
+# software distributed under the License is distributed on an
+# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+# KIND, either express or implied.  See the License for the
+# specific language governing permissions and limitations
+# under the License.
+
 cmake-*
 crcutil-*
 gflags-*

http://git-wip-us.apache.org/repos/asf/incubator-kudu/blob/31058c6c/www/index.html
----------------------------------------------------------------------
diff --git a/www/index.html b/www/index.html
index edc8f26..df3bbf8 100644
--- a/www/index.html
+++ b/www/index.html
@@ -1,3 +1,22 @@
+<!--
+//
+// Licensed to the Apache Software Foundation (ASF) under one
+// or more contributor license agreements.  See the NOTICE file
+// distributed with this work for additional information
+// regarding copyright ownership.  The ASF licenses this file
+// to you under the Apache License, Version 2.0 (the
+// "License"); you may not use this file except in compliance
+// with the License.  You may obtain a copy of the License at
+//
+//   http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing,
+// software distributed under the License is distributed on an
+// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+// KIND, either express or implied.  See the License for the
+// specific language governing permissions and limitations
+// under the License.
+-->
 <html>
 <body>
 <h1>Kudu Webserver</h1>
diff --git a/src/kudu/integration-tests/linked_list-test-util.h b/src/kudu/integration-tests/linked_list-test-util.h
index 854e103..0364d9c 100644
--- a/src/kudu/integration-tests/linked_list-test-util.h
+++ b/src/kudu/integration-tests/linked_list-test-util.h
@@ -177,11 +177,12 @@ class LinkedListChainGenerator {
   // 'chain_idx' is a unique ID for this chain. Chains with different indexes
   // will always generate distinct sets of keys (thus avoiding the possibility of
   // a collision even in a longer run).
-  explicit LinkedListChainGenerator(uint8_t chain_idx)
+  explicit LinkedListChainGenerator(int chain_idx)
     : chain_idx_(chain_idx),
       rand_(chain_idx * 0xDEADBEEF),
       prev_key_(0) {
-    CHECK_LT(chain_idx, 256);
+    CHECK_GE(chain_idx, 0);
+    CHECK_LT(chain_idx, 65536);
   }
 
   ~LinkedListChainGenerator() {
@@ -193,9 +194,9 @@ class LinkedListChainGenerator {
   }
 
   Status GenerateNextInsert(client::KuduTable* table, client::KuduSession* session) {
     // Encode the chain index in the lowest 8 bits so that different chains never
     // intersect.
-    int64_t this_key = (Rand64() << 8) | chain_idx_;
+    int64_t this_key = (Rand64() << 16) | chain_idx_;
     int64_t ts = GetCurrentTimeMicros();
 
     gscoped_ptr<client::KuduInsert> insert(table->NewInsert());
@@ -214,7 +215,7 @@ class LinkedListChainGenerator {
   }
 
  private:
-  const uint8_t chain_idx_;
+  const int chain_idx_;
 
   // This is a linear congruential random number generator, so it won't repeat until
   // it has exhausted its period (which is quite large)


[4/5] incubator-kudu git commit: Add ASL2.0 license headers to files missing it

Posted by jd...@apache.org.
Add ASL2.0 license headers to files missing it

Ran RAT manually and these were the files missing ASL that were not
licensed under some other license, such as BSD or MIT, and that were of
a file format that supports adding comments.

I'm working on integrating RAT but I didn't want to block these fixes or
the release on that.

Change-Id: I6ace596ce1fec648cc42edaed8fbca1d2bd941e0
Reviewed-on: http://gerrit.cloudera.org:8080/2178
Reviewed-by: Jean-Daniel Cryans
Tested-by: Kudu Jenkins


Project: http://git-wip-us.apache.org/repos/asf/incubator-kudu/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-kudu/commit/31058c6c
Tree: http://git-wip-us.apache.org/repos/asf/incubator-kudu/tree/31058c6c
Diff: http://git-wip-us.apache.org/repos/asf/incubator-kudu/diff/31058c6c

Branch: refs/heads/master
Commit: 31058c6cf3593c66d7b2e0c696cd533fb1db8510
Parents: 1ba7030
Author: Mike Percy <mp...@apache.org>
Authored: Tue Feb 16 21:28:29 2016 +0200
Committer: Jean-Daniel Cryans <jd...@gerrit.cloudera.org>
Committed: Wed Feb 17 00:03:16 2016 +0000

----------------------------------------------------------------------
 .gitignore                                 | 17 ++++++++++++++++
 build-support/jenkins/dummy-junit.xml      | 18 +++++++++++++++++
 build-support/tools/kudu-lint/.gitignore   | 17 ++++++++++++++++
 cmake_modules/FindBitshuffle.cmake         | 17 ++++++++++++++++
 cmake_modules/FindCrcutil.cmake            | 17 ++++++++++++++++
 cmake_modules/FindGFlags.cmake             | 17 ++++++++++++++++
 cmake_modules/FindGLog.cmake               | 17 ++++++++++++++++
 cmake_modules/FindGPerf.cmake              | 17 ++++++++++++++++
 cmake_modules/FindLibEv.cmake              | 17 ++++++++++++++++
 cmake_modules/FindLz4.cmake                | 17 ++++++++++++++++
 cmake_modules/FindProtobuf.cmake           | 17 ++++++++++++++++
 cmake_modules/FindSnappy.cmake             | 17 ++++++++++++++++
 cmake_modules/FindVmem.cmake               | 17 ++++++++++++++++
 cmake_modules/FindZlib.cmake               | 17 ++++++++++++++++
 docs/.gitignore                            | 17 ++++++++++++++++
 docs/images/.gitignore                     |  0
 docs/support/scripts/Gemfile               | 17 ++++++++++++++++
 docs/transaction_semantics.adoc            | 17 ++++++++++++++++
 docs/whitepaper/.gitignore                 | 17 ++++++++++++++++
 docs/whitepaper/kudu.tex                   | 18 ++++++++++++++++-
 docs/whitepaper/ycsb-data/combine-data.sh  | 17 ++++++++++++++++
 docs/whitepaper/ycsb-data/log-to-tsv.pl    | 17 ++++++++++++++++
 docs/whitepaper/ycsb-data/plots.R          | 17 ++++++++++++++++
 docs/whitepaper/ycsb-data/uniform-hbase.sh | 17 ++++++++++++++++
 docs/whitepaper/ycsb-data/uniform-kudu.sh  | 17 ++++++++++++++++
 docs/whitepaper/ycsb-data/zipf-hbase.sh    | 17 ++++++++++++++++
 docs/whitepaper/ycsb-data/zipfian-kudu.sh  | 17 ++++++++++++++++
 java/.gitignore                            | 17 ++++++++++++++++
 java/kudu-client/.gitignore                | 16 +++++++++++++++
 python/.gitignore                          | 27 ++++++++++++++-----------
 python/kudu/tests/__init__.py              | 18 +++++++++++++++++
 src/kudu/client/clientConfig.cmake.in      | 17 ++++++++++++++++
 src/kudu/scripts/ensure_cpu_scaling.sh     | 18 +++++++++++++++++
 thirdparty/.gitignore                      | 17 ++++++++++++++++
 www/index.html                             | 19 +++++++++++++++++
 35 files changed, 580 insertions(+), 13 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-kudu/blob/31058c6c/.gitignore
----------------------------------------------------------------------
@@ -193,9 +194,9 @@ class LinkedListChainGenerator {
 
   Status GenerateNextInsert(client::KuduTable* table, client::KuduSession* session) {
-    // Encode the chain index in the lowest 8 bits so that different chains never
+    // Encode the chain index in the lowest 16 bits so that different chains never
     // intersect.